import { Component, Input, Output, EventEmitter } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
var TreeViewComponent = (function () {
    function TreeViewComponent(rebirthNGConfig) {
        this.checkable = false;
        this.allowDraggable = false;
        this.allowMutipleSelected = false;
        this.nodeItemClicked = new EventEmitter();
        this.nodeItemDroped = new EventEmitter();
        this.nodeItemDbClicked = new EventEmitter();
        this.nodeItemCheckedChanged = new EventEmitter();
        this.nodeItemExpended = new EventEmitter();
        this.valueField = rebirthNGConfig.treeView.valueField;
        this.textField = rebirthNGConfig.treeView.textField;
        this.leafIcon = rebirthNGConfig.treeView.leafIcon;
        this.expendIcon = rebirthNGConfig.treeView.expendIcon;
        this.unExpendIcon = rebirthNGConfig.treeView.unExpendIcon;
    }
    TreeViewComponent.prototype.onNodeItemExpended = function (node) {
        this.nodeItemExpended.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemClicked = function (node) {
        if (!this.allowMutipleSelected) {
            if (this.selectNode && this.selectNode !== node) {
                this.selectNode.$$select = false;
            }
            this.selectNode = node;
        }
        this.nodeItemClicked.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemDbClicked = function (node) {
        this.nodeItemDbClicked.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemCheckedChanged = function (node) {
        this.nodeItemCheckedChanged.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemDroped = function ($event) {
        var _this = this;
        var target = $event.target;
        if (!target) {
            return;
        }
        var source = $event.data.data.node;
        var sourceParent = $event.data.data.parent;
        if (sourceParent && sourceParent[this.valueField]) {
            var matchNode = this.getTreeNodeById(this.treeData, sourceParent[this.valueField]);
            if (matchNode) {
                matchNode.children = matchNode.children.filter(function (nodeItem) { return nodeItem[_this.valueField] !== source[_this.valueField]; });
            }
        }
        else {
            if (this.treeData.length < 2) {
                return;
            }
            this.treeData = this.treeData.filter(function (nodeItem) { return nodeItem[_this.valueField] !== source[_this.valueField]; });
        }
        target.children = target.children || [];
        target.children.push(source);
        this.nodeItemDroped.emit($event);
    };
    TreeViewComponent.prototype.getSelectNode = function () {
        return this.getMatchedItems(this.treeData, '$$select');
    };
    TreeViewComponent.prototype.getCheckedNodes = function () {
        return this.getMatchedItems(this.treeData, '$$check');
    };
    TreeViewComponent.prototype.getTreeNodeById = function (items, id) {
        if (!items) {
            return;
        }
        for (var i = 0; i < items.length; i++) {
            var nodeItem = items[i];
            if (nodeItem[this.valueField] === id) {
                return nodeItem;
            }
            var matchNode = this.getTreeNodeById(nodeItem.children, id);
            if (matchNode) {
                return matchNode;
            }
        }
    };
    TreeViewComponent.prototype.getMatchedItems = function (items, field) {
        var _this = this;
        if (!items) {
            return [];
        }
        var nodes = [];
        items.forEach(function (nodeItem) {
            if (nodeItem[field]) {
                nodes.push(nodeItem[_this.valueField]);
            }
            nodes.push.apply(nodes, _this.getMatchedItems(nodeItem.children, field));
        });
        return nodes;
    };
    return TreeViewComponent;
}());
export { TreeViewComponent };
TreeViewComponent.decorators = [
    { type: Component, args: [{
                selector: 're-tree-view',
                template: "\n    <re-tree-panel [treeData]=\"treeData\" [textField]=\"textField\" [valueField]=\"valueField\"\n                   [iconField]=\"iconField\" [checkable]=\"checkable\" [allowDraggable]=\"allowDraggable\"\n                   [nodeItemTemplate]=\"nodeItemTemplate\"\n                   [nodeItemToolbarTemplate]=\"nodeItemToolbarTemplate\" [leafIcon]=\"leafIcon\" [expendIcon]=\"expendIcon\"\n                   [unExpendIcon]=\"unExpendIcon\" [allowMutipleSelected]=\"allowMutipleSelected\"\n                   (nodeItemCheckedChanged)=\"onNodeItemCheckedChanged($event)\">\n    </re-tree-panel>\n  ",
                styles: ["\n\n  "],
                exportAs: 'treeView'
            },] },
];
/** @nocollapse */
TreeViewComponent.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
]; };
TreeViewComponent.propDecorators = {
    'treeData': [{ type: Input },],
    'valueField': [{ type: Input },],
    'textField': [{ type: Input },],
    'iconField': [{ type: Input },],
    'checkable': [{ type: Input },],
    'allowDraggable': [{ type: Input },],
    'allowMutipleSelected': [{ type: Input },],
    'nodeItemTemplate': [{ type: Input },],
    'nodeItemToolbarTemplate': [{ type: Input },],
    'leafIcon': [{ type: Input },],
    'expendIcon': [{ type: Input },],
    'unExpendIcon': [{ type: Input },],
    'nodeItemClicked': [{ type: Output },],
    'nodeItemDroped': [{ type: Output },],
    'nodeItemDbClicked': [{ type: Output },],
    'nodeItemCheckedChanged': [{ type: Output },],
    'nodeItemExpended': [{ type: Output },],
};
//# sourceMappingURL=tree-view.component.js.map